@@ -19,21 +19,10 @@
 #ifndef MENU_H
 #define MENU_H
 
-#include <gtk/gtk.h>
-#include <gnome.h>
+void random_seed ();
+void undo_callback ();
+void redo_callback ();
+void help_about_callback ();
+void create_menus ();
 
-#define ELEMENTS(x) (sizeof (x) / sizeof (x [0]))
-
-/* Call backs... */
-int file_quit_callback (GtkWidget*, void* );
-int game_load_game_callback (GtkWidget*, void* );
-int file_select_game_callback (GtkWidget*, void* );
-int file_new_game_callback (GtkWidget*, void* );
-int game_hint_callback (GtkWidget*, void* );
-int undo_callback (GtkWidget*, void* );
-int redo_callback (GtkWidget*, void* );
-int restart_callback (GtkWidget*, void* );
-void help_about_callback (GtkWidget*, void* );
-
-void create_menus(GnomeApp *app);
 #endif
