@@ -123,7 +123,7 @@ void eval_installed_file (char *file)
     return;
   }
   
-  relative = g_copy_strings (GAMESDIR, file, NULL);
+  relative = g_strconcat (GAMESDIR, file, NULL);
   installed_filename = gnome_datadir_file (relative);
   gh_eval_file (installed_filename);
   g_free (installed_filename);
@@ -258,14 +258,7 @@ void timer_stop ()
 
 void create_sol_board ()
 {
-  gtk_widget_push_colormap (gdk_imlib_get_colormap ());
-  gtk_widget_push_visual (gdk_imlib_get_visual ());
-  
   playing_area = gtk_drawing_area_new ();
-  
-  gtk_widget_pop_visual ();
-  gtk_widget_pop_colormap ();
-  
   gtk_widget_set_events (playing_area, 
 			 gtk_widget_get_events (playing_area) | GAME_EVENTS);
   
@@ -450,6 +443,9 @@ int main (int argc, char *argv [])
   gnome_init_with_popt_table ("Aisleriot", VERSION, argc, argv,
 			      aisleriot_opts, 0, NULL);
 
+  gtk_widget_push_colormap (gdk_imlib_get_colormap ());
+  gtk_widget_push_visual (gdk_imlib_get_visual ());
+  
   splash_new ();
 
   splash_update (_("Initializing scheme..."), 0.20);
@@ -460,7 +456,7 @@ int main (int argc, char *argv [])
   gtk_signal_connect (GTK_OBJECT (gnome_master_client ()), "die",
 		      GTK_SIGNAL_FUNC (quit_app), NULL);
 
-  retrieve_state (gnome_cloned_client ());
+  retrieve_state (gnome_master_client ());
 
   dir = gnome_datadir_file (GAMESDIR);
   n_games = scandir (dir, &game_dents, is_game, alphasort);
