@@ -1,6 +1,6 @@
 /* gnome-stones - main.c
  *
- * Time-stamp: <1998/09/07 22:50:52 carsten>
+ * Time-stamp: <1998/11/28 13:39:56 hvr>
  *
  * Copyright (C) 1998 Carsten Schaar
  *
@@ -25,9 +25,11 @@
 #include <string.h>
 #include "game.h"
 #include "cave.h"
+#include "object.h"
 #include "status.h"
 #include "player.h"
 #include "preferences.h"
+#include "io.h"
 
 /* You should leave 'USE_GNOME_CANVAS' undefined, because this game
    currently doesn't support all features with gnome_canvas stuff
@@ -84,6 +86,42 @@ static gboolean       player_push       = FALSE;
 
 static char *default_message= N_("Gnome-Stones (c) 1998 Carsten Schaar");
 
+
+/****************************************************************************/
+/* Commandline options.  */
+
+
+static void 
+parse_func (poptContext ctx,
+	    enum poptCallbackReason reason,
+	    const struct poptOption *opt,
+	    const char *arg, void *data)
+{
+  int key = opt ? opt->val : 0;
+
+  printf ("Parsing commandline: key %i\n", key);
+
+  if (key == 1)
+    {
+      printf ("\"--discard-file %s\" found\n", arg);
+      /* Option: --discard-file  */
+      discard_session_file (arg);
+
+      exit (0);
+    }
+
+}
+
+
+/* Command-line arguments understood by this module.  */
+static const struct poptOption options[] = {
+  {NULL, '\0', POPT_ARG_CALLBACK, parse_func, 0, NULL, NULL},
+  {"discard-file", '\0', POPT_ARG_STRING, NULL, 1, 
+   N_("Config file to discard"), N_("CONFIG FILE")},
+  {NULL, '\0', 0, NULL, 0}
+};
+
+
 
 /****************************************************************************/
 
@@ -498,9 +536,7 @@ game_widget_create (void)
 
 #ifdef USE_GNOME_CANVAS
   /* Now for some experimantal gnome canvas stuff.  */
-  gnome_canvas_set_size (GNOME_CANVAS (canvas), 
-			 GAME_COLS*STONE_SIZE,
-			 GAME_ROWS*STONE_SIZE);
+  gtk_widget_set_usize (canvas, GAME_COLS*STONE_SIZE, GAME_ROWS*STONE_SIZE);
   gnome_canvas_set_scroll_region (GNOME_CANVAS (canvas),
 				  0, 0,
 				  GAME_COLS*STONE_SIZE,
@@ -776,7 +812,7 @@ countdown_timeout_function (gpointer data)
 	}
       
       if (cave->next)
-	newcave= cave_load (game, cave->next);
+	newcave= gstones_cave_load (game, cave->next);
 	
       curtain_start (newcave);
 
@@ -786,9 +822,6 @@ countdown_timeout_function (gpointer data)
 
 	  pos= gnome_score_log (player->score, NULL, TRUE);
 
-	  /* FIXME: somewhere is a bug, that makes this needed.  */
-	  if (pos > 10) pos= 0;
-
 	  gnome_scores_display ("Gnome-Stones", APP_NAME, NULL, pos);
 	  gnome_app_flash (GNOME_APP (app), _("Congratulations, you win!"));
 	}
@@ -943,18 +976,18 @@ iteration_timeout_function (gpointer data)
     {
       if (!(cave->flags & CAVE_PLAYER_EXISTS) && !cave->is_intermission)
 	{
-	  player_inc_lifes (player, -1);
+	  player_inc_lives (player, -1);
 	  
-	  if (player->lifes != 0)
+	  if (player->lives != 0)
 	    { 
 	      /* Restart cave.  */
-	      GStonesCave *newcave= cave_load (game, cave->name);
+	      GStonesCave *newcave= gstones_cave_load (game, cave->name);
 	      
 	      curtain_start (newcave);
 	    }
 	  else
 	    {
-	      /* That's it.  No lifes anymore.  */
+	      /* That's it.  No lives anymore.  */
 	      gint pos= gnome_score_log (player->score, NULL, TRUE);
 
 	      /* FIXME: somewhere is a bug, that makes this needed.  */
@@ -1024,7 +1057,7 @@ load_game (const gchar *filename, guint _start_cave)
     }
   
   /* Load game.  */
-  newgame= game_load (filename);
+  newgame= gstones_game_load (filename);
 
   if (newgame)
     {
@@ -1080,7 +1113,7 @@ game_start_cb (GtkWidget *widget, gpointer data)
   if (!player) return;
 
   tmp = g_list_nth (game->start_caves, start_cave);
-  cave= cave_load (game, tmp->data);
+  cave= gstones_cave_load (game, tmp->data);
   
   if (cave)
     curtain_start (cave);
@@ -1104,7 +1137,7 @@ quit_cb (GtkWidget *widget, gpointer data)
 static void
 show_scores_cb (GtkWidget *widget, gpointer data)
 {
-  gnome_scores_display ("Gnome-Stones", APP_NAME, NULL, (int) data);
+  gnome_scores_display ("Gnome-Stones", APP_NAME, NULL, GPOINTER_TO_INT (data));
 }
 
 
@@ -1135,14 +1168,14 @@ about_cb (GtkWidget *widget, gpointer data)
 static GnomeUIInfo game_menu[]= {
   {
     GNOME_APP_UI_ITEM,
-    N_("New"), N_("Start a new game"),
+    N_("_New"), N_("Start a new game"),
     game_start_cb, NULL, NULL,
     GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW,
-    'N', GDK_CONTROL_MASK, NULL
+    GNOME_KEY_NAME_NEW, GNOME_KEY_MOD_NEW, NULL
   },
   {
     GNOME_APP_UI_ITEM,
-    N_("Scores"), N_("Show highscore table"),
+    N_("_Scores..."), N_("Show highscore table"),
     show_scores_cb, (gpointer) 0, NULL,
     GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SCORES,
     0, (GdkModifierType) 0, NULL
@@ -1150,7 +1183,7 @@ static GnomeUIInfo game_menu[]= {
   GNOMEUIINFO_SEPARATOR,
   {
     GNOME_APP_UI_ITEM,
-    N_("Preferences..."), N_("Change Gnome-Stones preferences"),
+    N_("_Preferences..."), N_("Change Gnome-Stones preferences"),
     preferences_cb, (gpointer) 0, NULL,
     GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PREF,
     0, (GdkModifierType) 0, NULL
@@ -1158,10 +1191,10 @@ static GnomeUIInfo game_menu[]= {
   GNOMEUIINFO_SEPARATOR,
   {
     GNOME_APP_UI_ITEM,
-    N_("Exit"), N_("Exit Gnome Stones"),
+    N_("E_xit"), N_("Exit Gnome Stones"),
     quit_cb, NULL, NULL,
     GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_QUIT,
-    'Q', GDK_CONTROL_MASK, NULL
+    GNOME_KEY_NAME_EXIT, GNOME_KEY_MOD_EXIT, NULL
   },
   GNOMEUIINFO_END
 };
@@ -1169,7 +1202,7 @@ static GnomeUIInfo game_menu[]= {
 static GnomeUIInfo help_menu[]= {
   {
     GNOME_APP_UI_ITEM,
-    N_("About Gnome-Stones"), N_("Info about Gnome Stones"),
+    N_("_About Gnome-Stones"), N_("Info about Gnome Stones"),
     about_cb, NULL, NULL,
     GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT,
     0, (GdkModifierType) 0, NULL
@@ -1181,8 +1214,8 @@ static GnomeUIInfo help_menu[]= {
 
 static GnomeUIInfo main_menu[]= 
 {
-  GNOMEUIINFO_SUBTREE(N_("Game"), game_menu),
-  GNOMEUIINFO_SUBTREE(N_("Help"), help_menu),
+  GNOMEUIINFO_SUBTREE(N_("_Game"), game_menu),
+  GNOMEUIINFO_SUBTREE(N_("_Help"), help_menu),
   GNOMEUIINFO_END
 };
 
@@ -1193,7 +1226,7 @@ static GnomeUIInfo main_menu[]=
 
 
 static gboolean
-scan_public_game_directories (void)
+scan_public_game_directory (void)
 {
   game_directory_scan (CAVESDIR);
 
@@ -1202,17 +1235,45 @@ scan_public_game_directories (void)
 
 
 static gboolean
-scan_private_game_directories (void)
+scan_private_game_directory (void)
 {
-  char *path= gnome_util_home_file ("GnomeStonesGames");
+  char *dir= gnome_util_home_file ("gnomes-stones/games");
   
-  game_directory_scan (path);
+  game_directory_scan (dir);
 
-  g_free (path);
+  g_free (dir);
   return TRUE;
 }
 
 
+static gboolean
+scan_public_plugin_directory (void)
+{
+  char *dir= gnome_unconditional_libdir_file ("gnome-stones/objects/");
+
+  plugin_load_plugins_in_dir (dir);
+
+  g_free (dir);
+  return TRUE;
+}
+
+
+static gboolean
+scan_private_plugin_directory (void)
+{
+  char *dir= gnome_util_home_file ("gnomes-stones/objects");
+  
+  plugin_load_plugins_in_dir (dir);
+
+  g_free (dir);
+  return TRUE;
+}
+
+
+/*****************************************************************************/
+/* Startup sequence.  */
+
+
 typedef struct
 {
   gboolean (*function)(void);
@@ -1226,6 +1287,14 @@ StartupSequence startup_sequence[]=
     curtain_image_load,
     N_("Loading curtain image...")
   },
+  {
+    scan_private_plugin_directory,
+    N_("Scanning private object directory...")
+  },
+  {
+    scan_public_plugin_directory,
+    N_("Scanning public object directory...")
+  },
 #ifdef USE_GNOME_CANVAS
   {
     game_widget_fill,
@@ -1233,16 +1302,12 @@ StartupSequence startup_sequence[]=
   },
 #endif /* USE_GNOME_CANVAS */
   {
-    objects_register_all,
-    N_("Registering game objects...")
+    scan_private_game_directory,
+    N_("Scanning private game directory...")
   },
   {
-    scan_private_game_directories,
-    N_("Scanning private game directories...")
-  },
-  {
-    scan_public_game_directories,
-    N_("Scanning public game directories...")
+    scan_public_game_directory,
+    N_("Scanning public game directory...")
   },
   {
     preferences_restore,
@@ -1295,7 +1360,7 @@ main (int argc, char *argv[])
 
   gnome_score_init (APP_NAME);
 
-  gnome_init (APP_NAME, NULL, argc, argv, 0, NULL);
+  gnome_init_with_popt_table (APP_NAME, VERSION, argc, argv, options, 0, NULL);
 
   /* That's what a gnome application needs:  */
   app= gnome_app_new ("gnome-stones", _("Gnome-Stones"));
