@@ -95,7 +95,7 @@ void new_game(GtkWidget *widget, gpointer data)
 	gtk_minefield_restart(GTK_MINEFIELD(mfield));
 	gtk_widget_draw(mfield, NULL);
 	set_flabel(GTK_MINEFIELD(mfield));
-//        gtk_clock_start(GTK_CLOCK(clk));
+/*        gtk_clock_start(GTK_CLOCK(clk)); */
 }
 
 void setupdialog_destroy(GtkWidget *widget, gint mode)
@@ -109,6 +109,7 @@ void setupdialog_destroy(GtkWidget *widget, gint mode)
 void marks_changed(GtkWidget *widget, gpointer data)
 {
         set_flabel(GTK_MINEFIELD(widget));
+	gtk_clock_start(GTK_CLOCK(clk));
 }
 
 void lose_game(GtkWidget *widget, gpointer data)
@@ -193,12 +194,13 @@ void verify_ranges (void)
 
 void do_setup(GtkWidget *widget, gpointer data)
 {
-        guint oldxsize, oldysize, oldnmines, oldfsize;
+        guint oldxsize, oldysize, oldnmines, oldfsize, oldminesize;
   
 	oldxsize = xsize;
 	oldysize = ysize;
 	oldnmines = nmines;
         oldfsize = fsize;
+	oldminesize = minesize;
 
         xsize  = atoi(gtk_entry_get_text(GTK_ENTRY(xentry)));
 	ysize  = atoi(gtk_entry_get_text(GTK_ENTRY(yentry)));
@@ -225,6 +227,7 @@ void do_setup(GtkWidget *widget, gpointer data)
 	gnome_config_set_int("/gnomine/geometry/minesize", minesize);
 	gnome_config_set_int("/gnomine/geometry/mode",   fsize);
 	gnome_config_sync();
+	
 }
 
 void
@@ -418,11 +421,11 @@ GnomeUIInfo gamemenu[] = {
 	{GNOME_APP_UI_ITEM, N_("_Properties..."), NULL, setup_game, NULL, NULL,
 	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PROP, 0, 0, NULL},
 
-	{GNOME_APP_UI_ITEM, N_("_Scores"), NULL, top_ten, NULL, NULL,
+	{GNOME_APP_UI_ITEM, N_("S_cores"), NULL, top_ten, NULL, NULL,
 	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SCORES, 0, 0, NULL},
 
 	{GNOME_APP_UI_ITEM, N_("E_xit"), NULL, quit_game, NULL, NULL,
-	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'q', GDK_CONTROL_MASK, NULL},
+	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'x', GDK_CONTROL_MASK, NULL},
 
 	{GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL, NULL, NULL,
 	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL}
@@ -432,7 +435,7 @@ GnomeUIInfo helpmenu[] = {
 	{GNOME_APP_UI_HELP, NULL, NULL, "gnomine", NULL, NULL,
 	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
 
-	{GNOME_APP_UI_ITEM, N_("_About Gnome Mines"), NULL, about, NULL, NULL,
+	{GNOME_APP_UI_ITEM, N_("_About..."), NULL, about, NULL, NULL,
 	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT, 0, 0, NULL},
 
 	{GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL, NULL, NULL,
@@ -545,6 +548,7 @@ main (int argc, char *argv[])
 	  nmines = gnome_config_get_int("/gnomine/geometry/nmines=40");
 	if (minesize == -1){
 	  minesize = gnome_config_get_int("/gnomine/geometry/minesize=17");
+	  /* XXX is this necessary, verify_ranges() is just below. */
 	  if (minesize < 0)
 	    minesize = 1;
 	}
@@ -568,9 +572,7 @@ main (int argc, char *argv[])
 #endif /* ENABLE_NLS */
 
         window = gnome_app_new("gnomine", _("Gnome Mines"));
-        gtk_window_set_policy(GTK_WINDOW(window), FALSE, FALSE, TRUE);
 	gnome_app_create_menus(GNOME_APP(window), mainmenu);
-
 	
         gtk_signal_connect(GTK_OBJECT(window), "delete_event",
                            GTK_SIGNAL_FUNC(quit_game), NULL);
@@ -640,6 +642,7 @@ main (int argc, char *argv[])
 			   GTK_SIGNAL_FUNC(unlook_cell), NULL);
 	
 	gtk_widget_show(mfield);
+
         status_table = gtk_table_new(1, 4, TRUE);
 	gtk_box_pack_start(GTK_BOX(all_boxes), status_table, TRUE, TRUE, 0);
 
@@ -667,10 +670,13 @@ main (int argc, char *argv[])
         gtk_widget_show(status_table);
 	
 	gtk_widget_show(all_boxes);
-        gtk_widget_show(window);
 
 	new_game(mfield, NULL);
 
+        /* gtk_window_set_policy(GTK_WINDOW(window), FALSE, FALSE, TRUE); */
+
+        gtk_widget_show(window);
+
         gtk_main();
 
 	gtk_object_unref(GTK_OBJECT(client));
