@@ -19,11 +19,11 @@
  * For more details see the file COPYING.
  */
 
-#define GNOTHELLO_VERSION "0.2.0"
-#define PIXMAP_NAME "tiles.png"
+#define GNOTHELLO_VERSION "0.8.0"
 #define BLACK_TURN 1
 #define WHITE_TURN 31
 #define PIXMAP_FLIP_DELAY 20
+#define PIXMAP_STAGGER_DELAY 3
 #define COMPUTER_MOVE_DELAY 1000
 
 #define TILEWIDTH 60
@@ -31,9 +31,21 @@
 #define BOARDWIDTH TILEWIDTH * 8
 #define BOARDHEIGHT TILEHEIGHT * 8
 
+typedef struct _MoveHistory MoveHistory;
+
+struct _MoveHistory
+{
+        gint8 board[8][8];
+        gint8 x;
+        gint8 y;
+	gint8 me;
+};
+
 void new_game_cb(GtkWidget *widget, gpointer data);
 void new_net_game_cb(GtkWidget *widget, gpointer data);
 void quit_game_cb(GtkWidget *widget, gpointer data);
+void undo_move_cb(GtkWidget *widget, gpointer data);
+void redo_move_cb(GtkWidget *widget, gpointer data);
 void black_level_cb (GtkWidget *widget, gpointer data);
 void white_level_cb (GtkWidget *widget, gpointer data);
 void about_cb (GtkWidget *widget, gpointer data);
@@ -42,6 +54,12 @@ void comp_white_cb (GtkWidget *widget, gpointer data);
 void quick_moves_cb (GtkWidget *widget, gpointer data);
 void anim_cb (GtkWidget *widget, gpointer data);
 void anim_stagger_cb (GtkWidget *widget, gpointer data);
+void load_tiles_cb(GtkWidget *widget, gpointer data);
+void fill_menu(GtkWidget *menu);
+void set_selection(GtkWidget *widget, void *data);
+void free_str(GtkWidget *widget, void *data);
+void load_tiles_callback(GtkWidget *widget, void *data);
+void cancel(GtkWidget *widget, void *data);
 gint expose_event (GtkWidget *widget ,GdkEventExpose *event);
 gint configure_event (GtkWidget *widget, GdkEventConfigure *event);
 gint button_press_event (GtkWidget *widget, GdkEventButton *event);
@@ -50,10 +68,9 @@ void gui_draw_pixmap_buffer(gint which, gint x, gint y);
 gint flip_pixmaps(gpointer data);
 void init_new_game();
 void create_window();
-void create_menus();
-void create_drawing_area();
-void create_statusbar();
+void gui_status();
 void gui_message(gchar *message);
 guint check_computer_players();
+void load_pixmaps();
 
 extern guint whose_turn;
