@@ -18,11 +18,18 @@
 #define MAX_TILES 144
 #define MAX_TILES_STR "144"
 
+#define AREA_WIDTH 600
+#define AREA_HEIGHT 480
 #define TILE_WIDTH 40
 #define TILE_HEIGHT 56
 #define HALF_WIDTH 18
 #define HALF_HEIGHT 26
-#define MAH_VERSION "0.5.0"
+#define MAH_VERSION "0.99.1"
+
+#include <gnome.h>
+
+extern int xpos_offset;
+extern int ypos_offset;
 
 typedef struct _tilepos tilepos;     
 typedef struct _tile tile;
@@ -42,7 +49,7 @@ struct _tilepos {
 	int layer;
 };
 
-extern tilepos *pos ;
+extern tilepos *pos;
 
 struct _tile{
   int type;
@@ -53,6 +60,10 @@ struct _tile{
   int visible;
   int selected;
   int sequence;
+  int number;
+  GdkImlibImage *current_image;
+  GnomeCanvasItem *canvas_item;
+  GnomeCanvasItem *image_item;
 };
 
 extern tile tiles[MAX_TILES];
