@@ -318,22 +318,25 @@ void validate_tile (int t)
 /* Place tile in map at position f, with pic & type from t */
 void place_tile (int f, int t, int idx)
 {
+  int xoff, yoff;
 #ifdef PLACE_DEBUG
   printf ("Placing at\n") ;
   dump_tile(f) ;
 #endif
   tiles[f].visible = 1;
   tiles[f].selected = 0;
-  tiles[f].x = pos[f].x * (HALF_WIDTH-0) + 120 + (5 * pos[f].layer);
-  tiles[f].y = pos[f].y * (HALF_HEIGHT-0) + 25 - (4 * pos[f].layer);
+
+  tiles[f].x = pos[f].x * (HALF_WIDTH-0) + xpos_offset + (5 * pos[f].layer);
+  tiles[f].y = pos[f].y * (HALF_HEIGHT-0) + ypos_offset - (4 * pos[f].layer);
   tiles[f].layer = pos[f].layer;
+
   /*  if (tiles[f].layer>0)
       tiles[f].visible = 0 ;
       tiles[f].sequence = 0 ; */
 
   tiles[f].type = type_info[t].type;
   tiles[f].image = type_info[t].image[idx] ;
-
+  
   assert (dep_tree[f].free) ;
   assert (!dep_tree[f].filled) ;
   dep_tree[f].filled = 1 ; /* Lord */
